pub fn on_path(program: &str) -> boolExpand description
Whether a program can be run, by walking PATH. The real
is_installed behind parse_entry.
pub fn on_path(program: &str) -> boolWhether a program can be run, by walking PATH. The real
is_installed behind parse_entry.